package sun.swing;

import javax.swing.SwingUtilities;
import java.util.Collections;
import java.util.ArrayList;
import java.util.List;

public abstract class AccumulativeRunnable<T> implements Runnable
{
    private List<T> arguments;
    
    public AccumulativeRunnable() {
        this.arguments = null;
    }
    
    protected abstract void run(List<T> p0);
    
    @Override
    public final void run() {
        this.run(this.flush());
    }
    
    @SafeVarargs
    public final synchronized void add(T... elements) {
        boolean n = true;
        if (this.arguments == null) {
            n = false;
            this.arguments = new ArrayList();
        }
        Collections.addAll(this.arguments, elements);
        if (n == 0) {
            this.submit();
        }
    }
    
    protected void submit() {
        SwingUtilities.invokeLater(this);
    }
    
    private final synchronized List<T> flush() {
        List<Object> arguments = this.arguments;
        this.arguments = null;
        return arguments;
    }
}
